@@ -1,5 +1,4 @@
 from abc import ABCMeta
-from abc import abstractmethod
 
 
 class Callback(metaclass=ABCMeta):
@@ -37,6 +36,5 @@ class Callback(metaclass=ABCMeta):
     def on_init(self, ctx):
         pass
 
-    @abstractmethod
     def on_after_train(self, ctx):
         pass
