@@ -1,3 +1,3 @@
-from .logger_callback import Logger
 from .output_callback import OutputCallback
-from .plot.metrics_plotter import JupyterMetricsPlotter
+from .logger_callback import Logger
+from .plot.metrics_plotter import MetricsPlotter
